# agroweather

Fetch weather data from agrometeo.ch stations across Switzerland.

See {doc}`../examples/agroweather` for usage examples.

## API Reference

```{eval-rst}
.. automodule:: pyedautils.agroweather
   :members:
   :undoc-members:
   :show-inheritance:
```
